@@ -90,6 +90,7 @@ class NodeInfo(object):
         self.total_childs = 0
         self.levels = 0
         self.service = None
+        self.provider_node = None
 
         self._row = row
 
@@ -102,6 +103,9 @@ class NodeInfo(object):
             assert node_name
             self.name = node_name
             self.type = 'dead'
+            self.last_tick = None
+            self.paused = True
+            self.uptodate = False
             return
 
         self.name = row['node_name']
@@ -135,19 +139,6 @@ class NodeInfo(object):
             if a:
                 self.node_attrs = skytools.db_urldecode(a)
 
-    def __get_target_queue(self) -> Optional[str]:
-        qname = None
-        if self.type == LEAF:
-            if self.combined_queue:
-                qname = self.combined_queue
-            else:
-                return None
-        else:
-            qname = self.queue_name
-        if qname is None:
-            raise Exception("no target queue")
-        return qname
-
     def get_title(self) -> str:
         if self.service:
             return "%s (%s, %s)" % (self.name, self.type, self.service)
